NumberInputFormatter class

Inheritance

Constructors

NumberInputFormatter({num? min, num? max, num? step, int? precision, bool? stepStrictly})

Properties

hashCode → int
The hash code for this object.
no setterinherited
max → num?
最大可输入值
final
min → num?
最小可输入值
final
precision → int?
输入精度
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
step → num
步进值
final
stepStrictly → bool
是否严格步进
final

Methods

formatEditUpdate(TextEditingValue oldValue, TextEditingValue newValue) → TextEditingValue
Called when text is being typed or cut/copy/pasted in the EditableText.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited