TxPickerFormFieldState<T, V> class

Inheritance

Constructors

TxPickerFormFieldState()

Properties

bucket → RestorationBucket?
The RestorationBucket used for the restoration data of the RestorablePropertys registered to this mixin.
no setterinherited
clearable → bool
no setteroverride
context → BuildContext
The location in the tree where this widget builds.
no setterinherited
controller → TextEditingController?
no setterinherited
effectiveDecoration → InputDecoration
最终生效的装饰器
no setterinherited
effectiveLabel → Widget?
最终生效的 label
no setterinherited
errorText → String?
The current validation error returned by the FormField.validator callback, or the manually provided error message using the FormField.forceErrorText property.
no setterinherited
focusNode → FocusNode?
no setterinherited
hasError → bool
True if this field has any validation errors.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasInteractedByUser → bool
Returns true if the user has modified the value of this field.
no setterinherited
isEmpty → bool
no setterinherited
isEnabled → bool
no setterinherited
isValid → bool
True if the current value is valid.
no setterinherited
mounted → bool
Whether this State object is currently in a tree.
no setterinherited
obscureText → bool?
no setterinherited
prefixIcon → Widget?
头部图标
no setterinherited
restorationId → String?
The restoration ID used for the RestorationBucket in which the mixin will store the restoration data of all registered properties.
no setterinherited
restorePending → bool
Whether restoreState will be called at the beginning of the next build phase.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
suffixIcons → List<Widget>?
尾部图标
no setteroverride
value → T?
The current value of the form field.
no setterinherited
widget → TxPickerFormField<T, V>
The current configuration.
no setteroverride

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
inherited
clearError() → void
Clears any visible validation error for this field without resetting the field's value.
inherited
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChange(T? value) → void
选择项变更回调
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didToggleBucket(RestorationBucket? oldBucket) → void
Called when bucket switches between null and non-null values.
inherited
didUpdateRestorationId() → void
Must be called when the value returned by restorationId changes.
inherited
didUpdateWidget(covariant TxCommonTextFormField<T> oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
inherited
initState() → void
Called when this object is inserted into the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
registerForRestoration(RestorableProperty<Object?> property, String restorationId) → void
Registers a RestorableProperty for state restoration.
inherited
reset() → void
Resets the field to its initial value.
inherited
restoreState(RestorationBucket? oldBucket, bool initialRestore) → void
Called to initialize or restore the RestorablePropertys used by the State object.
inherited
save() → void
Calls the FormField's onSaved method with the current value.
inherited
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
setValue(T? value) → void
只修改值,不修改输入框文字
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
unregisterFromRestoration(RestorableProperty<Object?> property) → void
Unregisters a RestorableProperty from state restoration.
inherited
validate() → bool
Calls FormField.validator to set the errorText only if FormField.forceErrorText is null. When FormField.forceErrorText is not null, FormField.validator will not be called.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited