TxSegmentedFormField<T, V> class

Segmented 选择框表单

Inheritance

Constructors

TxSegmentedFormField({required List<T> source, required ValueMapper<T, String?> labelMapper, ValueMapper<T, V?>? valueMapper, ValueMapper<T, bool>? disabledWhen, IndexedDataWidgetBuilder<T>? iconBuilder, ValueMapper<T, String>? tooltipMapper, ButtonStyle? buttonStyle, bool? showSelectedIcon, bool? emptySelectionAllowed, Widget? selectedIcon, T? initialData, V? initialValue, TextAlign? textAlign, Key? key, FormFieldSetter<T>? onSaved, FormFieldValidator<T>? validator, bool? enabled, AutovalidateMode? autovalidateMode = AutovalidateMode.onUserInteraction, String? restorationId, InputDecoration? decoration, ValueChanged<T?>? onChanged, bool? required, bool? bordered = false, Widget? label, String? labelText, TextAlign? labelTextAlign, TextOverflow? labelOverflow, EdgeInsetsGeometry? padding, FieldActionsBuilder<T>? actionsBuilder, TextStyle? labelStyle, double? horizontalGap, Color? tileColor, Axis? layoutDirection, TxFormFieldBuilder<T>? trailingBuilder, Widget? leading, VisualDensity? visualDensity, ShapeBorder? shape, Color? iconColor, Color? textColor, TextStyle? leadingAndTrailingTextStyle, GestureTapCallback? onTap, double? minLeadingWidth, double? minLabelWidth, double? minVerticalPadding, bool? dense, bool? colon, Color? focusColor})

Properties

autovalidateMode → AutovalidateMode
Used to enable/disable this form field auto validation and update its error text.
finalinherited
bordered → bool?
是否显示边框
finalinherited
builder → FormFieldBuilder<T>
Function that returns the widget representing this form field.
finalinherited
decoration → InputDecoration?
要在文本字段周围显示的装饰。
finalinherited
enabled → bool
Whether the form is able to receive user input.
finalinherited
errorBuilder → FormFieldErrorBuilder?
Function that returns the widget representing the error to display.
finalinherited
forceErrorText → String?
An optional property that forces the FormFieldState into an error state by directly setting the FormFieldState.errorText property without running the validator function.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
hintText → String?
提示文字
finalinherited
initialValue → T?
An optional value to initialize the form field to, or null otherwise.
finalinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label → Widget?
参考 TxTile.label
finalinherited
labelText → String?
标题文字
finalinherited
onChanged → ValueChanged<T?>?
值变更回调
finalinherited
onReset → VoidCallback?
An optional method to call when the form field is reset via FormFieldState.reset.
finalinherited
onSaved → ValueChanged<T?>?
An optional method to call with the final value when the form is saved via FormState.save.
finalinherited
required → bool
是否必填
finalinherited
restorationId → String?
Restoration ID to save and restore the state of the form field.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textAlign → TextAlign?
文字对齐方向
finalinherited
validator → FormFieldValidator<T>?
An optional method that validates an input. Returns an error string to display if the input is invalid, or null otherwise.
finalinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → FormFieldState<T>
Creates the mutable state for this widget at a given location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited