TxTextFormField class

文本输入框表单

Inheritance

Constructors

TxTextFormField({bool? clearable, Key? key, FormFieldSetter<String>? onSaved, FormFieldValidator<String>? validator, bool? enabled, AutovalidateMode? autovalidateMode = AutovalidateMode.onUserInteraction, String? restorationId, InputDecoration? decoration, ValueChanged<String?>? onChanged, bool? required, String? initialValue, FocusNode? focusNode, String? hintText, TextAlign? textAlign, bool? bordered, TextEditingController? controller, UndoHistoryController? undoController, TextInputType? keyboardType, TextInputAction? textInputAction, TextCapitalization? textCapitalization, TextStyle? style, StrutStyle? strutStyle, TextAlignVertical? textAlignVertical, TextDirection? textDirection, bool? readOnly, bool? showCursor, bool? autofocus, MaterialStatesController? statesController, String? obscuringCharacter, bool? obscureText, bool? autocorrect, SmartDashesType? smartDashesType, SmartQuotesType? smartQuotesType, bool? enableSuggestions, int? maxLines, int? minLines, bool? expands, int? maxLength, MaxLengthEnforcement? maxLengthEnforcement, VoidCallback? onEditingComplete, ValueChanged<String>? onFieldSubmitted, AppPrivateCommandCallback? onAppPrivateCommand, List<TextInputFormatter>? inputFormatters, double? cursorWidth, double? cursorHeight, Radius? cursorRadius, bool? cursorOpacityAnimates, Color? cursorColor, Color? cursorErrorColor, BoxHeightStyle? selectionHeightStyle, BoxWidthStyle? selectionWidthStyle, Brightness? keyboardAppearance, EdgeInsets? scrollPadding, DragStartBehavior? dragStartBehavior, bool? enableInteractiveSelection, TextSelectionControls? selectionControls, ValueChanged<TxFormFieldState<String>>? onFieldTap, GestureTapCallback? onTap, bool? onTapAlwaysCalled, TapRegionCallback? onTapOutside, MouseCursor? mouseCursor, InputCounterWidgetBuilder? buildCounter, ScrollController? scrollController, ScrollPhysics? scrollPhysics, Iterable<String>? autofillHints, ContentInsertionConfiguration? contentInsertionConfiguration, Clip? clipBehavior, bool? scribbleEnabled, bool? enableIMEPersonalizedLearning, EditableTextContextMenuBuilder? contextMenuBuilder, bool? canRequestFocus, SpellCheckConfiguration? spellCheckConfiguration, TextMagnifierConfiguration? magnifierConfiguration, Widget? label, String? labelText, TextAlign? labelTextAlign, TextOverflow? labelOverflow, EdgeInsetsGeometry? padding, FieldActionsBuilder<String>? actionsBuilder, TextStyle? labelStyle, double? horizontalGap, Color? tileColor, Axis? layoutDirection, TxFormFieldBuilder<String>? trailingBuilder, Widget? leading, VisualDensity? visualDensity, ShapeBorder? shape, Color? iconColor, Color? textColor, TextStyle? leadingAndTrailingTextStyle, double? minLeadingWidth, double? minLabelWidth, double? minVerticalPadding, bool? dense, bool? colon, Color? focusColor})

Properties

autovalidateMode → AutovalidateMode
Used to enable/disable this form field auto validation and update its error text.
finalinherited
bordered → bool?
是否显示边框
finalinherited
builder → FormFieldBuilder<String>
Function that returns the widget representing this form field.
finalinherited
clearable → bool?
输入内容是否可清除
finalinherited
controller → TextEditingController?
参考 TextFormField.controller
finalinherited
decoration → InputDecoration?
要在文本字段周围显示的装饰。
finalinherited
displayTextMapper → ContextValueMapper<String, String>
输入框显示的文字生成器
finalinherited
enabled → bool
Whether the form is able to receive user input.
finalinherited
errorBuilder → FormFieldErrorBuilder?
Function that returns the widget representing the error to display.
finalinherited
focusNode → FocusNode?
焦点
finalinherited
forceErrorText → String?
An optional property that forces the FormFieldState into an error state by directly setting the FormFieldState.errorText property without running the validator function.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
hintText → String?
提示文字
finalinherited
initialValue → String?
An optional value to initialize the form field to, or null otherwise.
finalinherited
isEmpty → ValueMapper<String, bool>?
判断是否为 null 或者空
finalinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label → Widget?
参考 TxTile.label
finalinherited
labelText → String?
标题文字
finalinherited
obscureText → bool?
输入内容是否可清除
finalinherited
onChanged → ValueChanged<String?>?
值变更回调
finalinherited
onReset → VoidCallback?
An optional method to call when the form field is reset via FormFieldState.reset.
finalinherited
onSaved → ValueChanged<String?>?
An optional method to call with the final value when the form is saved via FormState.save.
finalinherited
readOnly → bool
是否只读
finalinherited
required → bool
是否必填
finalinherited
restorationId → String?
Restoration ID to save and restore the state of the form field.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textAlign → TextAlign?
文字对齐方向
finalinherited
validator → FormFieldValidator<String>?
An optional method that validates an input. Returns an error string to display if the input is invalid, or null otherwise.
finalinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → TxCommonTextFormFieldState<String>
Creates the mutable state for this widget at a given location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited