DefaultTxLocalizations class

Implemented types

Constructors

DefaultTxLocalizations()
const

Properties

addButtonLabel → String
Label for add buttons and menu items.
no setteroverride
captureTileLabel → String
Label for make video choice on image picker.
no setteroverride
clearButtonLabel → String
Label for Clear buttons and menu items.
no setteroverride
collapsedButtonLabel → String
Label for Collapsed buttons.
no setteroverride
customTitle → String
Title for custom items.
no setteroverride
datePickerTitle → String
Title for date picker bottom sheet;
no setteroverride
dateRangeDateSeparator → String
The character string used to separate the start time and end time of datetime range picker.
no setteroverride
datetimePickerTitle → String
Title for datetime picker bottom sheet;
no setteroverride
datetimeRangePickerTitle → String
Title for datetime range picker bottom sheet;
no setteroverride
detailDialogTitle → String
Title for detail dialog.
no setteroverride
dialogContent → String
Title text for default dialog;
no setteroverride
dialogTitle → String
Title for default dialog.
no setteroverride
doneButtonTooltip → String
Label for done buttons.
no setteroverride
drawButtonTooltip → String
Label for draw buttons.
no setteroverride
editButtonTooltip → String
Label for edit buttons.
no setteroverride
filterSheetLabel → String
Label for filter sheet.
no setteroverride
fullScreenButtonTooltip → String
Label for full screen buttons.
no setteroverride
fullScreenExitButtonTooltip → String
Label for exit full screen buttons.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
loadingLabel → String
Label for loading to describe a state of loading.
no setteroverride
monthPickerTitle → String
Title for month picker bottom sheet;
no setteroverride
moreButtonLabel → String
Label for More buttons.
no setteroverride
noCameraPermissionMessage → String
Message for shown when no camera permission.
no setteroverride
photographTileLabel → String
Label for take photo choice on image picker.
no setteroverride
pickerFormFieldHint → String
The default hint for the picker form fields.
no setteroverride
pickerTitle → String
Title for picker.
no setteroverride
previewButtonLabel → String
Label for Preview buttons and menu items.
no setteroverride
quickChoiceTitle → String
Title for quick choices.
no setteroverride
redoButtonTooltip → String
Label for redo buttons.
no setteroverride
removeButtonLabel → String
Label for remove buttons and menu items.
no setteroverride
resetButtonLabel → String
Label for reset button.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectFileButtonTooltip → String
Label for select file buttons.
no setteroverride
selectPhotoButtonLabel → String
Label for select photo buttons.
no setteroverride
selectPhotoTileLabel → String
Label for select photo choice on image picker.
no setteroverride
selectVideoTileLabel → String
Label for select video choice on image picker.
no setteroverride
shareButtonLabel → String
Label for Share buttons and menu items.
no setteroverride
signatureFormFieldHint → String
The default hint for the signature form fields.
no setteroverride
tableOperationColumnLabel → String
Label for operation column of Table
no setteroverride
textFormFieldHint → String
The default hint for the input form fields.
no setteroverride
theDayBeforeLabel → String
Label for select the day before.
no setteroverride
theNextDayLabel → String
Label for select the next day.
no setteroverride
timePickerTitle → String
Title for time picker bottom sheet;
no setteroverride
undoButtonTooltip → String
Label for undo buttons.
no setteroverride
unknownFileSizeLabel → String
Label for unknown file size on file list tile.
no setteroverride
videoSpeedLabel → String
Label for video speed.
no setteroverride
yearPickerTitle → String
Title for year picker bottom sheet;
no setteroverride

Methods

dateRangeMaximumDateLimitLabel(Duration duration) → String
The label used for the maximum time limit in the date range picker.
override
dateRangeMinimumDateLimitLabel(Duration duration) → String
The label used for the minimum time limit in the date range picker.
override
daysLabel(int number) → String
The label for day(s).
override
formatDuration(Duration duration) → String
Formats the time of the given Duration.
override
hoursLabel(int number) → String
The label for hour(s).
override
maximumFileLimitLabel(int number) → String
The label used for the maximum quantity limit in the file pickers.
override
maximumNumberLimitLabel(num number) → String
The label used to limit the maximum value of digital input.
override
maximumPhotoLimitLabel(int number) → String
The label used for the minimum quantity limit in the photo pickers.
override
maximumSelectableQuantityLimitLabel(int number) → String
The label used for the maximum quantity limit in the multi pickers.
override
minimumFileLimitLabel(int number) → String
The label used for the minimum quantity limit in the file pickers.
override
minimumNumberLimitLabel(num number) → String
The label used to limit the minimum value of digital input.
override
minimumPhotoLimitLabel(int number) → String
The label used for the maximum quantity limit in the photo pickers.
override
minimumSelectableQuantityLimitLabel(int number) → String
The label used for the minimum quantity limit in the multi pickers.
override
minutesLabel(int number) → String
The label for minute(s).
override
multiPickerFormFieldHint(String splitCharacter) → String
The default hint for the picker form fields which input enabled.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recentDaysLabel(int count) → String
Label for recent days choice on quick choices.
override
recentMonthsLabel(int count) → String
Label for recent months choice on quick choices.
override
recentWeeksLabel(int count) → String
Label for recent weeks choice on quick choices.
override
recentYearsLabel(int count) → String
Label for recent years choice on quick choices.
override
secondsLabel(int number) → String
The label for second(s).
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

load(Locale locale) → Future<TxLocalizations>