TxLocalizations class abstract

Implementers

Constructors

TxLocalizations()

Properties

addButtonLabel → String
Label for add buttons and menu items.
no setter
captureTileLabel → String
Label for make video choice on image picker.
no setter
clearButtonLabel → String
Label for Clear buttons and menu items.
no setter
collapsedButtonLabel → String
Label for Collapsed buttons.
no setter
customTitle → String
Title for custom items.
no setter
datePickerTitle → String
Title for date picker bottom sheet;
no setter
dateRangeDateSeparator → String
The character string used to separate the start time and end time of datetime range picker.
no setter
datetimePickerTitle → String
Title for datetime picker bottom sheet;
no setter
datetimeRangePickerTitle → String
Title for datetime range picker bottom sheet;
no setter
detailDialogTitle → String
Title for detail dialog.
no setter
dialogContent → String
Title text for default dialog;
no setter
dialogTitle → String
Title for default dialog.
no setter
doneButtonTooltip → String
Label for done buttons.
no setter
drawButtonTooltip → String
Label for draw buttons.
no setter
editButtonTooltip → String
Label for edit buttons.
no setter
filterSheetLabel → String
Label for filter sheet.
no setter
fullScreenButtonTooltip → String
Label for full screen buttons.
no setter
fullScreenExitButtonTooltip → String
Label for exit full screen buttons.
no setter
hashCode → int
The hash code for this object.
no setterinherited
loadingLabel → String
Label for loading to describe a state of loading.
no setter
monthPickerTitle → String
Title for month picker bottom sheet;
no setter
moreButtonLabel → String
Label for More buttons.
no setter
noCameraPermissionMessage → String
Message for shown when no camera permission.
no setter
photographTileLabel → String
Label for take photo choice on image picker.
no setter
pickerFormFieldHint → String
The default hint for the picker form fields.
no setter
pickerTitle → String
Title for picker.
no setter
previewButtonLabel → String
Label for Preview buttons and menu items.
no setter
quickChoiceTitle → String
Title for quick choices.
no setter
redoButtonTooltip → String
Label for redo buttons.
no setter
removeButtonLabel → String
Label for remove buttons and menu items.
no setter
resetButtonLabel → String
Label for reset button.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectFileButtonTooltip → String
Label for select file buttons.
no setter
selectPhotoButtonLabel → String
Label for select photo buttons.
no setter
selectPhotoTileLabel → String
Label for select photo choice on image picker.
no setter
selectVideoTileLabel → String
Label for select video choice on image picker.
no setter
shareButtonLabel → String
Label for Share buttons and menu items.
no setter
signatureFormFieldHint → String
The default hint for the signature form fields.
no setter
tableOperationColumnLabel → String
Label for operation column of Table
no setter
textFormFieldHint → String
The default hint for the input form fields.
no setter
theDayBeforeLabel → String
Label for select the day before.
no setter
theNextDayLabel → String
Label for select the next day.
no setter
timePickerTitle → String
Title for time picker bottom sheet;
no setter
undoButtonTooltip → String
Label for undo buttons.
no setter
unknownFileSizeLabel → String
Label for unknown file size on file list tile.
no setter
videoSpeedLabel → String
Label for video speed.
no setter
yearPickerTitle → String
Title for year picker bottom sheet;
no setter

Methods

dateRangeMaximumDateLimitLabel(Duration duration) → String
The label used for the maximum time limit in the date range picker.
dateRangeMinimumDateLimitLabel(Duration duration) → String
The label used for the minimum time limit in the date range picker.
daysLabel(int number) → String
The label for day(s).
formatDuration(Duration duration) → String
Formats the time of the given Duration.
hoursLabel(int number) → String
The label for hour(s).
maximumFileLimitLabel(int number) → String
The label used for the maximum quantity limit in the file pickers.
maximumNumberLimitLabel(num number) → String
The label used to limit the maximum value of digital input.
maximumPhotoLimitLabel(int number) → String
The label used for the minimum quantity limit in the photo pickers.
maximumSelectableQuantityLimitLabel(int number) → String
The label used for the maximum quantity limit in the multi pickers.
minimumFileLimitLabel(int number) → String
The label used for the minimum quantity limit in the file pickers.
minimumNumberLimitLabel(num number) → String
The label used to limit the minimum value of digital input.
minimumPhotoLimitLabel(int number) → String
The label used for the maximum quantity limit in the photo pickers.
minimumSelectableQuantityLimitLabel(int number) → String
The label used for the minimum quantity limit in the multi pickers.
minutesLabel(int number) → String
The label for minute(s).
multiPickerFormFieldHint(String splitCharacter) → String
The default hint for the picker form fields which input enabled.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recentDaysLabel(int count) → String
Label for recent days choice on quick choices.
recentMonthsLabel(int count) → String
Label for recent months choice on quick choices.
recentWeeksLabel(int count) → String
Label for recent weeks choice on quick choices.
recentYearsLabel(int count) → String
Label for recent years choice on quick choices.
secondsLabel(int number) → String
The label for second(s).
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

of(BuildContext context) → TxLocalizations