TxBorder class

盒子的边框,由四个边组成:顶部、右侧、底部、左侧。

边由 TxBorderSide 对象表示。

更多信息请参考Border

Inheritance

Constructors

TxBorder({TxBorderSide top = TxBorderSide.none, TxBorderSide right = TxBorderSide.none, TxBorderSide bottom = TxBorderSide.none, TxBorderSide left = TxBorderSide.none})
创建边框。
const
TxBorder.all({Color? color, double? width, BorderStyle? style, List<double>? dashPattern, LinearGradient? gradient})
一个统一的边框,所有边的颜色和宽度都相同。
factory
TxBorder.fromTxBorderSide(TxBorderSide side)
创建一个边都相同的边框。
const
TxBorder.symmetric({TxBorderSide vertical = TxBorderSide.none, TxBorderSide horizontal = TxBorderSide.none})
创建一个垂直和水平对称的边框。
const

Properties

bottom → BorderSide
The bottom side of this border.
finalinherited
dimensions → EdgeInsetsGeometry
The widths of the sides of this border represented as an EdgeInsets.
no setteroverride
hashCode → int
The hash code for this object.
no setteroverride
isUniform → bool
Whether all four sides of the border are identical. Uniform borders are typically more efficient to paint.
no setteroverride
left → BorderSide
The left side of this border.
finalinherited
preferPaintInterior → bool
Reports whether paintInterior is implemented.
no setterinherited
The right side of this border.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
top → BorderSide
The top side of this border.
finalinherited

Methods

add(ShapeBorder other, {bool reversed = false}) → TxBorder?
Attempts to create a new object that represents the amalgamation of this border and the other border.
override
getInnerPath(Rect rect, {TextDirection? textDirection}) → Path
Create a Path that describes the inner edge of the border.
inherited
getOuterPath(Rect rect, {TextDirection? textDirection}) → Path
Create a Path that describes the outer edge of the border.
inherited
lerpFrom(ShapeBorder? a, double t) → ShapeBorder?
Linearly interpolates from another ShapeBorder (possibly of another class) to this.
override
lerpTo(ShapeBorder? b, double t) → ShapeBorder?
Linearly interpolates from this to another ShapeBorder (possibly of another class).
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas canvas, Rect rect, {TextDirection? textDirection, BoxShape shape = BoxShape.rectangle, BorderRadius? borderRadius}) → void
Paints the border within the given Rect on the given Canvas.
override
paintInterior(Canvas canvas, Rect rect, Paint paint, {TextDirection? textDirection}) → void
Paint a canvas with the appropriate shape.
inherited
scale(double t) → TxBorder
Creates a copy of this border, scaled by the factor t.
override
toString() → String
A string representation of this object.
override

Operators

operator +(ShapeBorder other) → ShapeBorder
Creates a new border consisting of the two borders on either side of the operator.
inherited
operator ==(Object other) → bool
The equality operator.
override

Static Methods

merge(TxBorder a, TxBorder b) → TxBorder
Creates a Border that represents the addition of the two given Borders.
override