TxBorderSide class

盒子边框的一侧。

gradient 渐变色 dashPattern 虚线的格式

详细信息请参考 BorderSide

Inheritance
Annotations

Constructors

TxBorderSide({Color? color, double? width, BorderStyle? style, LinearGradient? gradient, List<double>? dashPattern, double strokeAlign = BorderSide.strokeAlignInside})
const

Properties

color → Color
The color of this side of the border.
finalinherited
dashPattern → List<double>?
虚线的格式
final
gradient → LinearGradient?
渐变色
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strokeAlign → double
The relative position of the stroke on a BorderSide in an OutlinedBorder or Border.
finalinherited
strokeInset → double
Get the amount of the stroke width that lies inside of the BorderSide.
no setterinherited
strokeOffset → double
The offset of the stroke, taking into account the stroke alignment.
no setterinherited
strokeOutset → double
Get the amount of the stroke width that lies outside of the BorderSide.
no setterinherited
style → BorderStyle
The style of this side of the border.
finalinherited
width → double
The width of this side of the border, in logical pixels.
finalinherited

Methods

copyWith({Color? color, double? width, BorderStyle? style, LinearGradient? gradient, double? strokeAlign, List<double>? dashPattern}) → TxBorderSide
Creates a copy of this border but with the given fields replaced with the new values.
override
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scale(double t) → TxBorderSide
Creates a copy of this border side description but with the width scaled by the factor t.
override
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toPaint() → Paint
Create a Paint object that, if used to stroke a line, will draw the line in this border's style.
inherited
toRectPaint(Rect rect) → Paint
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

canMerge(BorderSide a, BorderSide b) → bool
Whether the two given BorderSides can be merged using BorderSide.merge.
override
lerp(TxBorderSide a, TxBorderSide b, double t) → TxBorderSide
Linearly interpolate between two border sides.
override
merge(TxBorderSide a, TxBorderSide b) → TxBorderSide
Creates a BorderSide that represents the addition of the two given BorderSides.
override

Constants

none → const TxBorderSide