SpacingThemeData class

定义后代小部件的默认间距。

后代小部件使用 SpacingTheme.of(context) 获取当前的 SpacingThemeData 对象。 SpacingThemeData 的实例可以使用 SpacingThemeData.copyWith 进行自定义。

新增属性时需同时更新SpacingThemeData默认构造方法、copyWith方法、lerp方法

Inheritance
Annotations

Constructors

SpacingThemeData({double mini = 4.0, double small = 8.0, double medium = 12.0, double large = 16.0, double largest = 24.0})
const

Properties

edgeInsetsLarge → EdgeInsets
no setter
edgeInsetsLargest → EdgeInsets
no setter
edgeInsetsMedium → EdgeInsets
no setter
edgeInsetsMini → EdgeInsets
no setter
edgeInsetsSmall → EdgeInsets
no setter
hashCode → int
The hash code for this object.
no setterinherited
horizontalLarge → EdgeInsets
no setter
horizontalLargest → EdgeInsets
no setter
horizontalMedium → EdgeInsets
no setter
horizontalMini → EdgeInsets
no setter
horizontalSmall → EdgeInsets
no setter
large → double
final
largest → double
final
medium → double
final
mini → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
small → double
final
type → Object
The extension's type.
no setterinherited
verticalLarge → EdgeInsets
no setter
verticalLargest → EdgeInsets
no setter
verticalMedium → EdgeInsets
no setter
verticalMini → EdgeInsets
no setter
verticalSmall → EdgeInsets
no setter

Methods

copyWith({double? mini, double? small, double? medium, double? large, double? largest}) → ThemeExtension<SpacingThemeData>
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
override
lerp(covariant ThemeExtension<SpacingThemeData>? other, double t) → ThemeExtension<SpacingThemeData>
Linearly interpolate with another ThemeExtension object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited