Throttle class

节流与防抖

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

debounce(Function func, {String? id, int timeout = _defaultDuration}) → Function
防抖
throttle(dynamic func(), {String? id, int timeout = _defaultDuration, Function? funcWhenComplete}) → Function
节流