TxAnimatedIconButton class

动画图标按钮

Inheritance

Constructors

TxAnimatedIconButton({required AnimatedIconData? icon, Key? key, Animation<double>? animation, Duration? duration, Duration? reverseDuration, double? iconSize, VisualDensity? visualDensity, EdgeInsetsGeometry? padding, AlignmentGeometry? alignment, double? splashRadius, Color? focusColor, Color? hoverColor, Color? color, Color? splashColor, Color? highlightColor, Color? disabledColor, VoidCallback? onPressed, MouseCursor? mouseCursor, FocusNode? focusNode, bool autofocus = false, String? tooltip, bool? enableFeedback, BoxConstraints? constraints, ButtonStyle? style})
const
TxAnimatedIconButton.builder({required AnimatedIconBuilder? builder, Key? key, Animation<double>? animation, Duration? duration, Duration? reverseDuration, double? iconSize, VisualDensity? visualDensity, EdgeInsetsGeometry? padding, AlignmentGeometry? alignment, double? splashRadius, Color? focusColor, Color? hoverColor, Color? color, Color? splashColor, Color? highlightColor, Color? disabledColor, VoidCallback? onPressed, MouseCursor? mouseCursor, FocusNode? focusNode, bool autofocus = false, String? tooltip, bool? enableFeedback, BoxConstraints? constraints, ButtonStyle? style})
const

Properties

alignment → AlignmentGeometry?
参考IconButton.alignment
final
animation → Animation<double>?
动画
final
autofocus → bool
参考IconButton.autofocus
final
builder → AnimatedIconBuilder?
动画图标构造方法
final
color → Color?
参考IconButton.color
final
constraints → BoxConstraints?
参考IconButton.constraints
final
disabledColor → Color?
参考IconButton.disabledColor
final
duration → Duration?
动画时间
final
enableFeedback → bool?
参考IconButton.enableFeedback
final
focusColor → Color?
参考IconButton.focusColor
final
focusNode → FocusNode?
参考IconButton.focusNode
final
hashCode → int
The hash code for this object.
no setterinherited
highlightColor → Color?
参考IconButton.highlightColor
final
hoverColor → Color?
参考IconButton.hoverColor
final
icon → AnimatedIconData?
动画图标
final
iconSize → double?
参考IconButton.iconSize
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
mouseCursor → MouseCursor?
参考IconButton.mouseCursor
final
onPressed → VoidCallback?
参考IconButton.onPressed
final
padding → EdgeInsetsGeometry?
参考IconButton.padding
final
reverseDuration → Duration?
反向动画时间
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
splashColor → Color?
参考IconButton.splashColor
final
splashRadius → double?
参考IconButton.splashRadius
final
style → ButtonStyle?
参考IconButton.style
final
tooltip → String?
参考IconButton.tooltip
final
visualDensity → VisualDensity?
参考IconButton.visualDensity
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<TxAnimatedIconButton>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited