TxBottomSheet class

默认样式的底部弹出面板

包含标题栏、内容区域和底部操作按钮,支持自定义各个部分的内容和样式

Inheritance

Constructors

TxBottomSheet({required Widget content, Key? key, Widget? header, String? title, double? titleSpacing, bool? centerTitle, Widget? leading, double? leadingWidth, bool automaticallyImplyLeading = true, List<Widget>? actions, VoidCallback? onConfirm, VoidCallback? onCancel, String? textConfirm, String? textCancel, EdgeInsetsGeometry? padding, EdgeInsetsGeometry? contentPadding = _contentPadding, Widget? footer, ActionsPosition? actionsPosition})
const

Properties

actions → List<Widget>?
final
actionsPosition → ActionsPosition
final
automaticallyImplyLeading → bool
final
centerTitle → bool?
final
content → Widget
final
contentPadding → EdgeInsetsGeometry?
final
final
hashCode → int
The hash code for this object.
no setterinherited
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leading → Widget?
final
leadingWidth → double?
final
onCancel → VoidCallback?
final
onConfirm → VoidCallback?
final
padding → EdgeInsetsGeometry?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textCancel → String?
final
textConfirm → String?
final
title → String?
final
titleSpacing → double?
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited