TxButtonBarThemeData class

与 TxButtonBarTheme 一起使用来定义后代 TxButtonBar 小部件的默认属性值。

有关详细信息,请参阅各个 TxButtonBar 属性。

Inheritance
Annotations

Constructors

TxButtonBarThemeData({ButtonStyle? mainButtonStyle, ButtonStyle? secondaryButtonStyle, EdgeInsetsGeometry? buttonPadding, ButtonTextTheme? buttonTextTheme, double? buttonHeight, double? buttonMinWidth, ButtonBarLayoutBehavior? layoutBehavior, bool? buttonAlignedDropdown})
const

Properties

buttonAlignedDropdown → bool?
final
buttonHeight → double?
final
buttonMinWidth → double?
final
buttonPadding → EdgeInsetsGeometry?
final
buttonTextTheme → ButtonTextTheme?
final
hashCode → int
The hash code for this object.
no setterinherited
layoutBehavior → ButtonBarLayoutBehavior?
final
mainButtonStyle → ButtonStyle?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondaryButtonStyle → ButtonStyle?
final
type → Object
The extension's type.
no setterinherited

Methods

copyWith({ButtonStyle? mainButtonStyle, ButtonStyle? secondaryButtonStyle, EdgeInsetsGeometry? buttonPadding, ButtonTextTheme? buttonTextTheme, double? buttonHeight, double? buttonMinWidth, ButtonBarLayoutBehavior? layoutBehavior, bool? buttonAlignedDropdown}) → ThemeExtension<TxButtonBarThemeData>
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
override
lerp(covariant ThemeExtension<TxButtonBarThemeData>? other, double t) → ThemeExtension<TxButtonBarThemeData>
Linearly interpolate with another ThemeExtension object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited