TxCellThemeData class

与 TxCellTheme 一起使用来定义后代 TxCell 小部件的默认属性值。

有关详细信息,请参阅各个 TxCell 属性。

Inheritance
Annotations

Constructors

TxCellThemeData({bool? dense, Color? iconColor, EdgeInsetsGeometry? padding, double? gap, double? minLeadingWidth, double? minLabelWidth, VisualDensity? visualDensity, TextStyle? labelTextStyle, TextStyle? contentTextStyle, TextStyle? leadingTextStyle, double? minVerticalPadding, TextAlign? contentTextAlign})
const

Properties

contentTextAlign → TextAlign?
final
contentTextStyle → TextStyle?
final
dense → bool?
final
gap → double?
final
hashCode → int
The hash code for this object.
no setterinherited
iconColor → Color?
final
labelTextStyle → TextStyle?
final
leadingTextStyle → TextStyle?
final
minLabelWidth → double?
final
minLeadingWidth → double?
final
minVerticalPadding → double?
final
padding → EdgeInsetsGeometry?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → Object
The extension's type.
no setterinherited
visualDensity → VisualDensity?
final

Methods

copyWith({bool? dense, Color? iconColor, EdgeInsetsGeometry? padding, double? gap, double? minLeadingWidth, double? minLabelWidth, VisualDensity? visualDensity, TextStyle? labelTextStyle, TextStyle? contentTextStyle, double? minVerticalPadding, TextStyle? leadingTextStyle, TextAlign? contentTextAlign, int? contentMaxLines}) → TxCellThemeData
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
override
lerp(covariant ThemeExtension<TxCellThemeData>? other, double t) → ThemeExtension<TxCellThemeData>
Linearly interpolate with another ThemeExtension object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited