TxDataGrid class

数据展示栅格组件

Inheritance

Constructors

TxDataGrid({required List<Widget> rows, Key? key, Decoration? decoration, EdgeInsetsGeometry? padding, double? spacing})
创建描述数据表的小组件。
const
TxDataGrid.fromMap(Map<String, dynamic> data, {Key? key, int columnNum = 1, EdgeInsetsGeometry? padding, Decoration? decoration, double? spacing, Map<int, Widget>? slots, bool? dense, VisualDensity? visualDensity, double? minLabelWidth, double? minLeadingWidth, double? horizontalGap, TextStyle? contentTextStyle, TextStyle? labelTextStyle, TextAlign? contentTextAlign, EdgeInsetsGeometry? rowPadding, Decoration? rowDecoration, double? columnSpacing, int? contentMaxLines})
创建由data参数派生出的描述数据表的小组件。

Properties

decoration → Decoration?
栅格的背景和边框装饰
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
padding → EdgeInsetsGeometry?
内边距
final
rows → List<Widget>
要在每行中显示的数据(不包括包含列标题的行)。
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spacing → double?
每个数据列的内容之间的水平边距。
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited