TxDataRow class

TxDataGrid的行配置和单元格数据

必须为要在表中显示的每一行提供一个行配置。TxDataGrid 对象的列表作为“rows”参数传递给 TxDataGrid.new 构造函数。

表的这一行的数据在 TxDataRow 对象的 cells 属性中提供。

Inheritance

Constructors

TxDataRow({required List<Widget> cells, Decoration? decoration, double? spacing, EdgeInsetsGeometry? padding, Key? key})
为 TxDataGrid 的行创建配置。
const

Properties

cells → List<Widget>
此行的数据。
final
decoration → Decoration?
数据行的背景和边框装饰
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
padding → EdgeInsetsGeometry?
内边距
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spacing → double?
cells 之间的间距
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map<String, dynamic> data, {int columnNum = 2, Map<int, Widget>? slots, bool? dense, VisualDensity? visualDensity, double? minLabelWidth, double? minLeadingWidth, double? horizontalGap, TextStyle? contentTextStyle, TextStyle? labelTextStyle, TextAlign? contentTextAlign, EdgeInsetsGeometry? padding, Decoration? decoration, double? spacing, int? contentMaxLines}) → List<Widget>
通过指定 data 数据生成 TxDataRow 列表