TxDatePickerButton class

一个用于选择日期的按钮小部件

Inheritance

Constructors

TxDatePickerButton({Key? key, DateTime? initialDate, DateTime? minimumDate, DateTime? maximumDate, ValueChanged<DateTime>? onDateSelect, bool? showWeekday, ButtonStyle? buttonStyle, Widget? prefixIcon, Widget? suffixIcon, String? format})
创建一个日期选择按钮
const

Properties

buttonStyle → ButtonStyle?
按钮样式
final
format → String?
时间格式化方式
final
hashCode → int
The hash code for this object.
no setterinherited
initialDate → DateTime?
初始时间
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maximumDate → DateTime?
可选择的最晚时间
final
minimumDate → DateTime?
可选择的最早时间
final
onDateSelect → ValueChanged<DateTime>?
日期选择回调
final
prefixIcon → Widget?
展示在日期前的组件,一般为一个日历小图标
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showWeekday → bool?
是否显示周工作日
final
suffixIcon → Widget?
展示在日期后的组件吗,一般为一个向下的图标
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<TxDatePickerButton>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited