DateRangeMonthQuickChoice class

Inheritance

Constructors

DateRangeMonthQuickChoice({int value = 1})
const

Properties

datetimeRange → DateTimeRange<DateTime>
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
now → DateTime
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
finalinherited

Methods

getLabelText(BuildContext context) → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited