DateRangeQuickChoice class abstract

Implementers

Constructors

DateRangeQuickChoice({required int value})
const

Properties

datetimeRange → DateTimeRange<DateTime>
no setter
hashCode → int
The hash code for this object.
no setterinherited
now → DateTime
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
final

Methods

getLabelText(BuildContext context) → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited