TimeRange class

Annotations

Constructors

TimeRange({required TimeOfDay start, required TimeOfDay end})
Creates a date range for the given start and end TimeOfDay.
TimeRange.fromDateRange(DateTimeRange<DateTime> dateRange)

Properties

duration → Duration
Returns a Duration of the time between start and end.
no setter
end → TimeOfDay
The end of the range of dates.
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → TimeOfDay
The start of the range of dates.
final

Methods

format({String? format, String? separator}) → String
格式化时间范围 format 可以是预定义格式的key,也可以是自定义格式字符串 separator 开始时间和结束时间的分隔符 支持的格式:
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDateRange([DateTime? date]) → DateTimeRange<DateTime>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override