TxVerticalDivider class

一条细垂直线,两边都有填充。

相比于VerticalDivider增加了虚线配置。

详细信息参考VerticalDivider

Inheritance

Constructors

TxVerticalDivider({Key? key, double? width, double? thickness, double? indent, double? endIndent, Color? color, List<double>? dashPattern, LinearGradient? gradient})
创建一个 Material Design 垂直分隔线。
const

Properties

color → Color?
The color to use when painting the line.
finalinherited
dashPattern → List<double>?
虚线格式
final
endIndent → double?
The amount of empty space under the divider.
finalinherited
gradient → LinearGradient?
渐变色
final
hashCode → int
The hash code for this object.
no setterinherited
indent → double?
The amount of empty space on top of the divider.
finalinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
radius → BorderRadiusGeometry?
The amount of radius for the border of the divider.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thickness → double?
The thickness of the line drawn within the divider.
finalinherited
width → double?
The divider's width.
finalinherited

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited