RadialMenuCenterButton class

位于 RadialMenu 中心的按钮,控制其打开关闭状态。

Inheritance

Constructors

RadialMenuCenterButton({required bool isOpen, required Animation<double> openCloseAnimationController, Key? key, Animation<double>? activateAnimationController, VoidCallback? onPressed, Color? iconColor, Color? closedColor, Color? openedColor, double size = _defaultButtonSize})

Properties

activateAnimationController → Animation<double>?
当按下 RadialMenu 中的项目时的动画。
final
closedColor → Color?
处于关闭状态时的背景颜色。
final
hashCode → int
The hash code for this object.
no setterinherited
iconColor → Color?
绘制图标时使用的颜色。
final
isOpen → bool
菜单的打开关闭状态。
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onPressed → VoidCallback?
final
openCloseAnimationController → Animation<double>
驱动 RadialMenu 开闭的动画。
final
openedColor → Color?
处于打开状态时的背景颜色。
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → double
按钮的大小。
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited