RadialMenuItem<T> class

RadialMenu中的一项

类型T是每项代表的值的类型. 给定菜单中的所有条目必须表示具有一致类型的值。

Inheritance

Constructors

RadialMenuItem({required Widget child, Key? key, T? value, String? tooltip, Color? backgroundColor, double? size = _defaultButtonSize, Color? iconColor})
const

Properties

backgroundColor → Color?
按钮的背景色
final
child → Widget
树中此小部件下方的小部件
final
hashCode → int
The hash code for this object.
no setterinherited
iconColor → Color?
绘制子图标时使用的颜色。
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → double?
按钮的大小。
final
tooltip → String?
描述按下按钮时将发生的操作的提示性文字.
final
value → T?
如果用户选择此菜单项的返回值
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited