TxHelpTooltipIcon class

帮助提示按钮图标

Inheritance

Constructors

TxHelpTooltipIcon({required String? message, EdgeInsetsGeometry? iconPadding, bool solid = false, Key? key, InlineSpan? richMessage, double? height, EdgeInsetsGeometry? padding, EdgeInsetsGeometry? margin = const EdgeInsets.symmetric(horizontal: 12.0), double? verticalOffset, bool? preferBelow, bool? excludeFromSemantics, Decoration? decoration, TextStyle? textStyle, TextAlign? textAlign, Duration? waitDuration, Duration? showDuration, TooltipTriggerMode? triggerMode, bool? enableFeedback, TooltipTriggeredCallback? onTriggered})

Properties

child → Widget?
The widget below this widget in the tree.
finalinherited
constraints → BoxConstraints?
Constrains the size of the Tooltip's message.
finalinherited
decoration → Decoration?
Specifies the tooltip's shape and background color.
finalinherited
enableFeedback → bool?
Whether the tooltip should provide acoustic and/or haptic feedback.
finalinherited
enableTapToDismiss → bool
Whether the tooltip can be dismissed by tap.
finalinherited
excludeFromSemantics → bool?
Whether the tooltip's message or richMessage should be excluded from the semantics tree.
finalinherited
exitDuration → Duration?
The length of time that a pointer must have stopped hovering over a tooltip's widget before the tooltip will be hidden.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
height → double?
The minimum height of the Tooltip's message.
finalinherited
ignorePointer → bool?
Whether this tooltip should be invisible to hit testing.
finalinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
margin → EdgeInsetsGeometry?
The empty space that surrounds the tooltip.
finalinherited
message → String?
The text to display in the tooltip.
finalinherited
mouseCursor → MouseCursor?
The cursor for a mouse pointer when it enters or is hovering over the widget.
finalinherited
onTriggered → TooltipTriggeredCallback?
Called when the RawTooltip is triggered programmatically, on tap, or on long press.
finalinherited
padding → EdgeInsetsGeometry?
The amount of space by which to inset the Tooltip's message.
finalinherited
positionDelegate → TooltipPositionDelegate?
A custom position delegate function for computing where the tooltip should be positioned.
finalinherited
preferBelow → bool?
Whether the tooltip defaults to being displayed below the widget.
finalinherited
richMessage → InlineSpan?
The rich text to display in the tooltip.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showDuration → Duration?
The length of time that the tooltip will be shown after a long press is released (if triggerMode is TooltipTriggerMode.longPress) or a tap is released (if triggerMode is TooltipTriggerMode.tap).
finalinherited
textAlign → TextAlign?
How the message of the tooltip is aligned horizontally.
finalinherited
textStyle → TextStyle?
The style to use for the message of the tooltip.
finalinherited
triggerMode → TooltipTriggerMode?
The TooltipTriggerMode that will show the tooltip.
finalinherited
verticalOffset → double?
The vertical gap between the widget and the displayed tooltip.
finalinherited
waitDuration → Duration?
The length of time that a pointer must hover over a tooltip's widget before the tooltip will be shown.
finalinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<Tooltip>
Creates the mutable state for this widget at a given location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited