TxMatchingText class

在一组文本中高亮显示查询文字的小部件。

详细属性请参考Text

Inheritance

Constructors

TxMatchingText(String text, {Key? key, String? query, TextStyle? style, TextStyle? matchedStyle, Color? matchedColor, StrutStyle? strutStyle, TextAlign? textAlign, TextDirection? textDirection, Locale? locale, bool? softWrap, TextOverflow? overflow, TextScaler? textScaler, int? maxLines, String? semanticsLabel, TextWidthBasis? textWidthBasis})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
locale → Locale?
用于在相同的 Unicode 字符可以选择时选择字体根据语言环境呈现不同。
final
matchedColor → Color?
匹配文字颜色
final
matchedStyle → TextStyle?
匹配文字样式
final
maxLines → int?
文本跨越的可选最大行数,必要时换行。如果文本超过给定的行数,将根据给定的行数截断 到 overflow。
final
overflow → TextOverflow?
应该如何处理视觉溢出。
final
query → String?
查询的文字
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
semanticsLabel → String?
An alternative semantics label for this text.
final
softWrap → bool?
文本是否应该在软换行处中断。
final
strutStyle → StrutStyle?
final
style → TextStyle?
文字样式
final
text → String
显示的文字
final
textAlign → TextAlign?
文本应该如何水平对齐。
final
textDirection → TextDirection?
文本的方向。
final
textScaler → TextScaler?
每个逻辑像素的字体像素数。
final
textWidthBasis → TextWidthBasis?
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited