TxMultiCascadePicker<T, V> class

多选级联选择器

Inheritance

Constructors

TxMultiCascadePicker({required List<T> source, required ValueMapper<T, String?> labelMapper, required ValueMapper<T, V?>? valueMapper, required ValueMapper<T, List<T>?> childrenMapper, required ValueChanged<List<T>?>? onChanged, List<T>? initialData, ValueMapper<T, bool>? disabledWhen, Key? key, MultiPickerItemBuilder<T>? itemBuilder, ListTileThemeData? listTileTheme, Widget? placeholder, int? maxCount, bool? linkage, MultiPickerActionBarBuilder<T>? actionBarBuilder, MultiPickerSelectedItemBuilder<T>? selectedItemBuilder, bool? parentCheckable, DataWidgetBuilder<T>? subtitleBuilder, bool? showSearchField})
TxMultiCascadePicker.fromMapList({required List<Map> source, ValueChanged<List<Map>?>? onChanged, String? valueKey, String? labelKey, String? idKey, String? pidKey, String? rootId, Key? key, MultiPickerItemBuilder<Map>? itemBuilder, ValueMapper<Map, bool>? disabledWhen, List<Map>? initialData, int? maxCount, bool? linkage, MultiPickerActionBarBuilder<Map>? actionBarBuilder, MultiPickerSelectedItemBuilder<Map>? selectedItemBuilder, DataWidgetBuilder<Map>? subtitleBuilder, ListTileThemeData? listTileTheme, Widget? placeholder, bool? parentCheckable, bool? showSearchField})
通过给定非树型数据数组创建一个级联选择器

Properties

actionBarBuilder → MultiPickerActionBarBuilder<T>?
操作栏构造器
finalinherited
childrenMapper → ValueMapper<T, List<T>?>
数据的子节点
final
disabledWhen → ValueMapper<T, bool>?
数据是否可选
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
initialData → List<T>?
初始值
finalinherited
itemBuilder → MultiPickerItemBuilder<T>?
选择项构造器
finalinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelMapper → ValueMapper<T, String?>
数据展示给用户的标签
finalinherited
linkage → bool
父节点是否与子节点关联
final
listTileTheme → ListTileThemeData?
列表项主题
finalinherited
maxCount → int?
最大选择个数
finalinherited
onChanged → ValueChanged<List<T>?>?
选择变更回调
finalinherited
parentCheckable → bool
父节点是否可选
final
placeholder → Widget?
未选择数据时的提示组件
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedItemBuilder → MultiPickerSelectedItemBuilder<T>?
已选择项构造器
finalinherited
showSearchField → bool
是否显示搜索栏
finalinherited
source → List<T>
数据源
finalinherited
subtitleBuilder → DataWidgetBuilder<T>?
副标题构造器
finalinherited
valueMapper → ValueMapper<T, V?>
数据的值
finalinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → TxMultiPickerBaseState<T, V>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited