TxPanelThemeData class

与 TxPanelTheme 一起使用来定义后代 TxPanel 小部件的默认属性值。

有关详细信息,请参阅各个 TxPanel 属性。

Inheritance
Annotations

Constructors

TxPanelThemeData({bool? dense, ShapeBorder? shape, Color? selectedColor, Color? iconColor, Color? textColor, EdgeInsetsGeometry? padding, EdgeInsetsGeometry? margin, Color? panelColor, Color? selectedPanelColor, double? horizontalTitleGap, double? verticalGap, double? minLeadingWidth, bool? enableFeedback, MaterialStateProperty<MouseCursor?>? mouseCursor, VisualDensity? visualDensity, TextStyle? contentTextStyle, TextStyle? titleTextStyle, TextStyle? subtitleTextStyle, TextStyle? leadingAndTrailingTextStyle, ListTileTitleAlignment? titleAlignment, Color? focusColor, Color? splashColor, Color? hoverColor, Color? highlightColor})
const

Properties

contentTextStyle → TextStyle?
覆盖 TxPanel.contentTextStyle 的默认值。
final
dense → bool?
覆盖 TxPanel.dense 的默认值。
final
enableFeedback → bool?
覆盖 TxPanel.enableFeedback 的默认值。
final
focusColor → Color?
覆盖 TxPanel.focusColor 的默认值。
final
hashCode → int
The hash code for this object.
no setterinherited
highlightColor → Color?
覆盖 TxPanel.highlightColor 的默认值。
final
horizontalTitleGap → double?
覆盖 TxPanel.horizontalTitleGap 的默认值。
final
hoverColor → Color?
覆盖 TxPanel.hoverColor 的默认值。
final
iconColor → Color?
覆盖 TxPanel.iconColor 的默认值。
final
leadingAndTrailingTextStyle → TextStyle?
覆盖 TxPanel.leadingAndTrailingTextStyle 的默认值。
final
margin → EdgeInsetsGeometry?
覆盖 TxPanel.margin 的默认值。
final
minLeadingWidth → double?
覆盖 TxPanel.minLeadingWidth 的默认值。
final
mouseCursor → MaterialStateProperty<MouseCursor?>?
覆盖 TxPanel.mouseCursor 的默认值。
final
padding → EdgeInsetsGeometry?
覆盖 TxPanel.padding 的默认值。
final
panelColor → Color?
覆盖 TxPanel.panelColor 的默认值。
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedColor → Color?
覆盖 TxPanel.selectedColor 的默认值。
final
selectedPanelColor → Color?
覆盖 TxPanel.selectedPanelColor 的默认值。
final
shape → ShapeBorder?
覆盖 TxPanel.shape 的默认值。
final
splashColor → Color?
覆盖 TxPanel.splashColor 的默认值。
final
subtitleTextStyle → TextStyle?
重写 TxPanel.subtitleTextStyle 的默认值。
final
textColor → Color?
覆盖 TxPanel.textColor 的默认值。
final
titleAlignment → ListTileTitleAlignment?
如果指定,则覆盖 TxPanel.titleAlignment 的默认值。
final
titleTextStyle → TextStyle?
重写 TxPanel.titleTextStyle 的默认值。
final
type → Object
The extension's type.
no setterinherited
verticalGap → double?
覆盖 TxPanel.verticalGap 的默认值。
final
visualDensity → VisualDensity?
覆盖 TxPanel.visualDensity 的默认值。
final

Methods

copyWith({bool? dense, ShapeBorder? shape, Color? selectedColor, Color? iconColor, Color? textColor, EdgeInsetsGeometry? padding, EdgeInsetsGeometry? margin, Color? panelColor, Color? selectedPanelColor, double? horizontalTitleGap, double? minLeadingWidth, double? verticalGap, bool? enableFeedback, MaterialStateProperty<MouseCursor?>? mouseCursor, VisualDensity? visualDensity, TextStyle? titleTextStyle, TextStyle? subtitleTextStyle, TextStyle? leadingAndTrailingTextStyle, TextStyle? contentTextStyle, ListTileTitleAlignment? titleAlignment, Color? focusColor, Color? splashColor, Color? hoverColor, Color? highlightColor}) → ThemeExtension<TxPanelThemeData>
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
override
lerp(covariant ThemeExtension<TxPanelThemeData>? other, double t) → ThemeExtension<TxPanelThemeData>
Linearly interpolate with another ThemeExtension object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited