TxPickerBase<T, D, V> class abstract

选择器基础配置

Inheritance
Implementers

Constructors

TxPickerBase({required List<T> source, required ValueMapper<T, String?> labelMapper, D? initialData, ValueChanged<D?>? onChanged, ValueMapper<T, V?>? valueMapper, DataWidgetBuilder<T>? subtitleBuilder, ValueMapper<T, bool>? disabledWhen, Widget? placeholder, bool? showSearchField, ListTileThemeData? listTileTheme, Key? key})

Properties

disabledWhen → ValueMapper<T, bool>?
数据是否可选
final
hashCode → int
The hash code for this object.
no setterinherited
initialData → D?
初始值
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelMapper → ValueMapper<T, String?>
数据展示给用户的标签
final
listTileTheme → ListTileThemeData?
列表项主题
final
onChanged → ValueChanged<D?>?
选择变更回调
final
placeholder → Widget?
未选择数据时的提示组件
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showSearchField → bool
是否显示搜索栏
final
source → List<T>
数据源
final
subtitleBuilder → DataWidgetBuilder<T>?
副标题构造器
final
valueMapper → ValueMapper<T, V?>
数据的值
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → TxPickerBaseState<T, D, V>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited