TxGradientCircularProgressIndicator class

环形渐变进度指示器

Inheritance

Constructors

TxGradientCircularProgressIndicator({double? radius, List<Color>? colors, Key? key, double strokeWidth = 2.0, List<double>? stops, bool strokeCapRound = false, Color? backgroundColor, double totalAngle = 2 * math.pi, double? value})
const

Properties

backgroundColor → Color?
进度条背景色
final
colors → List<Color>?
渐变色数组
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
radius → double?
圆的半径
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stops → List<double>?
渐变色的终止点,对应colors属性
final
strokeCapRound → bool
两端是否为圆角
final
strokeWidth → double
粗细
final
totalAngle → double
进度条的总弧度,2PI为整圆,小于2PI则不是整圆
final
value → double?
当前进度,取值范围 0.0-1.0
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited