TxRadio<T> class

一个Material风格的单选按钮。

用于在多个互斥值之间进行选择。 当一组中的一个单选按钮被选中时,该组中的其他单选按钮将停止 被选中。 这些值的类型为“T”,即 Radio 类的类型参数。 枚举通常用于此目的。

单选按钮本身不保持任何状态。 相反,选择选项会调用 onChanged 回调,将 value 作为 参数传递。 如果 groupValue 和 value 匹配,则将选择此选项。 大多数小部件将通过 调用 State.setState 更新单选按钮的 groupValue 来响应 onChanged。

Inheritance

Constructors

TxRadio({required T value, required T? groupValue, required ValueChanged<T?>? onChanged, Key? key, MouseCursor? mouseCursor, bool toggleable = false, Color? activeColor, MaterialStateProperty<Color?>? fillColor, Color? focusColor, Color? hoverColor, MaterialStateProperty<Color?>? overlayColor, double? splashRadius, MaterialTapTargetSize? materialTapTargetSize, VisualDensity? visualDensity, FocusNode? focusNode, bool autofocus = false, OutlinedBorder? shape, BorderSide? side})
创建一个Material风格的单选按钮
const

Properties

activeColor → Color?
选择此单选按钮时使用的颜色。
final
autofocus → bool
True if this widget will be selected as the initial focus when no other node in its scope is currently focused.
final
fillColor → MaterialStateProperty<Color?>?
在所有 MaterialState 中填充单选按钮的颜色。
final
focusColor → Color?
单选按钮的 Material 具有输入焦点时的颜色。
final
focusNode → FocusNode?
An optional focus node to use as the focus node for this widget.
final
groupValue → T?
一组单选按钮的当前选定值。
final
hashCode → int
The hash code for this object.
no setterinherited
hoverColor → Color?
当指针悬停在收音机上方时,单选按钮 Material 的颜色。
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
materialTapTargetSize → MaterialTapTargetSize?
Configures the minimum size of the tap target.
final
mouseCursor → MouseCursor?
鼠标指针进入或悬停在小部件上时的光标。
final
onChanged → ValueChanged<T?>?
当用户选择此单选按钮时调用。
final
overlayColor → MaterialStateProperty<Color?>?
The color for the radio's Material.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shape → OutlinedBorder?
The shape of the checkbox's Material.
final
side → BorderSide?
The color and width of the checkbox's border.
final
splashRadius → double?
The splash radius of the circular Material ink response.
final
toggleable → bool
如果允许通过在选中时再次选择此单选按钮将其返回到不确定状态,则设置为 true。
final
value → T
此单选按钮表示的值。
final
visualDensity → VisualDensity?
Defines how compact the radio's layout will be.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<TxRadio<T>>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

width → const double
单选框小部件的宽度。