TxRadioThemeData class

定义后代 TxRadio 小部件的默认属性值。

后代小部件使用 TxRadioTheme.of(context) 获取当前的 TxRadioThemeData 对象。 TxRadioThemeData 的实例可以使用 TxRadioThemeData.copyWith 进行自定义。

默认情况下,所有 TxRadioThemeData 属性均为“null”。 如果为 null,TxRadio 将使用 来自 ThemeData 的值(如果它们存在),否则它将根据整体 Theme 的 colorScheme 提供自己的默认值。 有关详细信息,请参阅各个 TxRadio 属性。

Inheritance
Mixed-in types
Annotations

Constructors

TxRadioThemeData({MaterialStateProperty<MouseCursor?>? mouseCursor, MaterialStateProperty<Color?>? fillColor, MaterialStateProperty<Color?>? overlayColor, double? splashRadius, MaterialTapTargetSize? materialTapTargetSize, VisualDensity? visualDensity, OutlinedBorder? shape, BorderSide? side})
创建可用于 ThemeData.extension<TxRadioThemeData>() 的主题。
const

Properties

fillColor → MaterialStateProperty<Color?>?
The color that fills the checkbox, in all WidgetStates.
final
hashCode → int
The hash code for this object.
no setteroverride
materialTapTargetSize → MaterialTapTargetSize?
Configures the minimum size of the tap target.
final
mouseCursor → MaterialStateProperty<MouseCursor?>?
The cursor for a mouse pointer when it enters or is hovering over the widget.
final
overlayColor → MaterialStateProperty<Color?>?
The color for the checkbox's Material.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shape → OutlinedBorder?
The shape of the checkbox's Material.
final
side → BorderSide?
The color and width of the checkbox's border.
final
splashRadius → double?
The splash radius of the circular Material ink response.
final
type → Object
The extension's type.
no setterinherited
visualDensity → VisualDensity?
Defines how compact the checkbox's layout will be.
final

Methods

copyWith({MaterialStateProperty<MouseCursor?>? mouseCursor, MaterialStateProperty<Color?>? fillColor, MaterialStateProperty<Color?>? checkColor, MaterialStateProperty<Color?>? overlayColor, double? splashRadius, MaterialTapTargetSize? materialTapTargetSize, VisualDensity? visualDensity, OutlinedBorder? shape, BorderSide? side}) → TxRadioThemeData
创建此对象的副本,但将给定字段替换为新值。
override
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
lerp(covariant ThemeExtension<TxRadioThemeData>? other, double t) → ThemeExtension<TxRadioThemeData>
Linearly interpolate with another ThemeExtension object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override