CustomTabBar class abstract

Inheritance
Implementers

Constructors

CustomTabBar({required List<Widget> tabs, Key? key, TabController? controller, EdgeInsetsGeometry? padding, Color? indicatorColor, bool automaticIndicatorColorAdjustment = true, double indicatorWeight = 2.0, EdgeInsetsGeometry indicatorPadding = EdgeInsets.zero, UnderlineTabIndicator? indicator, TabBarIndicatorSize? indicatorSize, Color? labelColor, Color? unselectedLabelColor, TextStyle? labelStyle, TextStyle? unselectedLabelStyle, EdgeInsetsGeometry? labelPadding, ValueChanged<int>? onTap, bool isPrimary = true})
const

Properties

automaticIndicatorColorAdjustment → bool
参考TabBar.automaticIndicatorColorAdjustment
final
controller → TabController?
参考TabBar.controller
final
hashCode → int
The hash code for this object.
no setterinherited
indicator → UnderlineTabIndicator?
参考TabBar.indicator
final
indicatorColor → Color?
参考TabBar.indicatorColor
final
indicatorPadding → EdgeInsetsGeometry
参考TabBar.indicatorPadding
final
indicatorSize → TabBarIndicatorSize?
参考TabBar.indicatorSize
final
indicatorWeight → double
参考TabBar.indicatorWeight
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelColor → Color?
参考TabBar.labelColor
final
labelPadding → EdgeInsetsGeometry?
参考TabBar.labelPadding
final
labelStyle → TextStyle?
参考TabBar.labelStyle
final
onTap → ValueChanged<int>?
参考TabBar.onTap
final
padding → EdgeInsetsGeometry?
参考TabBar.padding
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tabHasTextAndIcon → bool
参考TabBar.tabHasTextAndIcon
no setter
tabs → List<Widget>
参考TabBar.tabs
final
unselectedLabelColor → Color?
参考TabBar.unselectedLabelColor
final
unselectedLabelStyle → TextStyle?
参考TabBar.unselectedLabelStyle
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<CustomTabBar>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited