TabIndicatorDecoration class

Annotations

Constructors

TabIndicatorDecoration({Color? color, BorderRadius? borderRadius, Gradient? gradient, BlendMode? backgroundBlendMode})
const

Properties

backgroundBlendMode → BlendMode?
应用于指示器的 color 或 gradient 背景的混合模式。
final
borderRadius → BorderRadius?
第一个和最后一个的圆角大小。
final
color → Color?
要填充指示器背景的颜色。
final
gradient → Gradient?
填充指示器时使用的渐变。
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override