TxTabBarView class

Inheritance

Constructors

TxTabBarView({required List<Widget> tabs, required Widget body, Key? key, TabController? controller, EdgeInsetsGeometry? padding, EdgeInsetsGeometry? tabBarPadding, Color? indicatorColor, double indicatorWeight = 0.0, EdgeInsetsGeometry indicatorPadding = EdgeInsets.zero, UnderlineTabIndicator? indicator, bool automaticIndicatorColorAdjustment = true, TabBarIndicatorSize? indicatorSize, Color? labelColor, Color? unselectedLabelColor, TextStyle? labelStyle, TextStyle? unselectedLabelStyle, EdgeInsetsGeometry? labelPadding, ValueChanged<int>? onTap, BoxDecoration? decoration, BoxDecoration? unSelectedTabDecoration, double? heightDifference})
const

Properties

automaticIndicatorColorAdjustment → bool
参考TabBar.automaticIndicatorColorAdjustment
finalinherited
body → Widget
页面主体
final
controller → TabController?
参考TabBar.controller
finalinherited
decoration → BoxDecoration?
装饰器
final
hashCode → int
The hash code for this object.
no setterinherited
heightDifference → double?
未选择的Tab高度差
final
indicator → UnderlineTabIndicator?
参考TabBar.indicator
finalinherited
indicatorColor → Color?
参考TabBar.indicatorColor
finalinherited
indicatorPadding → EdgeInsetsGeometry
参考TabBar.indicatorPadding
finalinherited
indicatorSize → TabBarIndicatorSize?
参考TabBar.indicatorSize
finalinherited
indicatorWeight → double
参考TabBar.indicatorWeight
finalinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelColor → Color?
参考TabBar.labelColor
finalinherited
labelPadding → EdgeInsetsGeometry?
参考TabBar.labelPadding
finalinherited
labelStyle → TextStyle?
参考TabBar.labelStyle
finalinherited
onTap → ValueChanged<int>?
参考TabBar.onTap
finalinherited
padding → EdgeInsetsGeometry?
参考TabBar.padding
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tabHasTextAndIcon → bool
参考TabBar.tabHasTextAndIcon
no setterinherited
tabs → List<Widget>
参考TabBar.tabs
finalinherited
unselectedLabelColor → Color?
参考TabBar.unselectedLabelColor
finalinherited
unselectedLabelStyle → TextStyle?
参考TabBar.unselectedLabelStyle
finalinherited
unSelectedTabDecoration → BoxDecoration?
未选择的Tab装饰器
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<CustomTabBar>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited