TxTile class

一个域组件布局容器

Inheritance

Constructors

TxTile({required Widget content, Key? key, Widget? label, String? labelText, TextAlign? labelTextAlign, TextOverflow? labelOverflow, EdgeInsetsGeometry? padding, List<Widget>? actions, TextStyle? labelStyle, double? horizontalGap, Color? tileColor, Axis? layoutDirection, Widget? trailing, Widget? leading, VisualDensity? visualDensity, ShapeBorder? shape, Color? iconColor, Color? textColor, TextStyle? leadingAndTrailingTextStyle, bool enabled = true, GestureTapCallback? onTap, double? minLeadingWidth, bool? dense, double? minLabelWidth, double? minVerticalPadding, bool? colon, bool focused = false, Color? focusColor})

Properties

actions → List<Widget>?
操作按钮
final
colon → bool?
是否显示冒号
final
content → Widget
内容
final
dense → bool?
参考 ListTile.dense
final
enabled → bool
参考 ListTile.enabled
final
focusColor → Color?
选中的文字和图标颜色
final
focused → bool
是否选中
final
hashCode → int
The hash code for this object.
no setterinherited
horizontalGap → double?
label、content、trailing 间距
final
iconColor → Color?
参考 ListTile.iconColor
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label → Widget?
描述输入字段的可选小部件。
final
labelOverflow → TextOverflow?
label 文字溢出处理方式
final
labelStyle → TextStyle?
label 文字样式
final
labelTextAlign → TextAlign?
label 文字的对齐方式
final
layoutDirection → Axis?
label与表单框排列的方向
final
leading → Widget?
参考 ListTile.leading
final
leadingAndTrailingTextStyle → TextStyle?
参考 ListTile.leadingAndTrailingTextStyle
final
minLabelWidth → double?
限制 label 的最小宽度。
final
minLeadingWidth → double?
参考 ListTile.minLeadingWidth
final
minVerticalPadding → double?
最小纵向内边距。
final
onTap → GestureTapCallback?
参考 ListTile.onTap
final
padding → EdgeInsetsGeometry?
内边距
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shape → ShapeBorder?
参考 ListTile.shape
final
textColor → Color?
参考 ListTile.textColor
final
tileColor → Color?
背景颜色
final
trailing → Widget?
操作按钮
final
visualDensity → VisualDensity?
参考 ListTile.visualDensity。
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited