TxTileThemeData class

与 TxTileTheme 一起使用来定义后代 TxTile 小部件的默认属性值。

有关详细信息,请参阅各个 TxTile 属性。

Inheritance
Annotations

Constructors

TxTileThemeData({TextStyle? labelStyle, TextAlign? labelTextAlign, TextOverflow? labelOverflow, EdgeInsetsGeometry? padding, double? horizontalGap, Color? tileColor, Axis? layoutDirection, bool? dense, ShapeBorder? shape, Color? iconColor, Color? textColor, TextStyle? leadingAndTrailingTextStyle, double? minLeadingWidth, VisualDensity? visualDensity, double? minLabelWidth, double? minVerticalPadding, bool? colon, Color? focusColor})
const

Properties

colon → bool?
覆盖 TxTile.colon 的默认值。
final
dense → bool?
覆盖 TxTile.dense 的默认值。
final
focusColor → Color?
覆盖 TxTile.focusColor 的默认值。
final
hashCode → int
The hash code for this object.
no setteroverride
horizontalGap → double?
覆盖 TxTile.horizontalGap 的默认值。
final
iconColor → Color?
覆盖 TxTile.iconColor 的默认值。
final
labelOverflow → TextOverflow?
覆盖 TxTile.labelOverflow 的默认值。
final
labelStyle → TextStyle?
覆盖 TxTile.labelStyle 的默认值。
final
labelTextAlign → TextAlign?
覆盖 TxTile.labelTextAlign 的默认值。
final
layoutDirection → Axis?
覆盖 TxTile.layoutDirection 的默认值。
final
leadingAndTrailingTextStyle → TextStyle?
覆盖 TxTile.leadingAndTrailingTextStyle 的默认值。
final
minLabelWidth → double?
覆盖 TxTile.minLabelWidth 的默认值。
final
minLeadingWidth → double?
覆盖 TxTile.minLeadingWidth 的默认值。
final
minVerticalPadding → double?
覆盖 TxTile.minVerticalPadding 的默认值。
final
padding → EdgeInsetsGeometry?
覆盖 TxTile.padding 的默认值。
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shape → ShapeBorder?
覆盖 TxTile.shape 的默认值。
final
textColor → Color?
覆盖 TxTile.textColor 的默认值。
final
tileColor → Color?
覆盖 TxTile.tileColor 的默认值。
final
type → Object
The extension's type.
no setterinherited
visualDensity → VisualDensity?
覆盖 TxTile.visualDensity 的默认值。
final

Methods

copyWith({Color? tileColor, TextStyle? labelStyle, TextAlign? labelTextAlign, TextOverflow? labelOverflow, EdgeInsetsGeometry? padding, Axis? layoutDirection, double? horizontalGap, bool? dense, ShapeBorder? shape, Color? iconColor, Color? textColor, TextStyle? leadingAndTrailingTextStyle, double? minLeadingWidth, double? minLabelWidth, double? minVerticalPadding, VisualDensity? visualDensity, bool? colon, Color? focusColor}) → ThemeExtension<TxTileThemeData>
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
override
lerp(covariant ThemeExtension<TxTileThemeData>? other, double t) → ThemeExtension<TxTileThemeData>
Linearly interpolate with another ThemeExtension object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override