TxTip class

一个Material风格的用于提示信息的小组件

Inheritance

Constructors

TxTip(String? data, {Key? key, Widget? icon, EdgeInsetsGeometry? margin, EdgeInsetsGeometry? padding, Color? backgroundColor, Color? foregroundColor, TextStyle? textStyle, BorderRadius? borderRadius, VisualDensity? visualDensity, VoidCallback? onClose})
创建一个提示小组件
const
TxTip.rich(InlineSpan? textSpan, {Key? key, Widget? icon, EdgeInsetsGeometry? margin, EdgeInsetsGeometry? padding, Color? backgroundColor, Color? foregroundColor, TextStyle? textStyle, BorderRadius? borderRadius, VisualDensity? visualDensity, VoidCallback? onClose})
使用textSpan创建一个提示
const
TxTip.type({required TipType type, required String? data, Key? key, EdgeInsetsGeometry? margin, EdgeInsetsGeometry? padding, TextStyle? textStyle, BorderRadius? borderRadius, VisualDensity? visualDensity, VoidCallback? onClose})
根据类型创建一个提示小组件

Properties

backgroundColor → Color?
在data后绘制的颜色
final
borderRadius → BorderRadius?
如果非空,此框的角由此 BorderRadius 圆化。
final
data → String?
要显示的文本。
final
foregroundColor → Color?
提示的 Text 和 Icon 小部件后代的颜色。
final
hashCode → int
The hash code for this object.
no setterinherited
icon → Widget?
树中此小部件下方的小部件。
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
margin → EdgeInsetsGeometry?
提示周围的空白空间
final
onClose → VoidCallback?
当用户点击关闭按钮时调用。
final
padding → EdgeInsetsGeometry?
内部空白空间。data被放置在这个填充中。
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textSpan → InlineSpan?
要显示为InlineSpan的文本。
final
textStyle → TextStyle?
后代Text小部件的样式。
final
visualDensity → VisualDensity?
定义提示布局的紧凑程度。
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited