TxTipTheme class

将单选框主题应用于后代 TxTip 小部件。

后代小部件使用 TxTipTheme.of 获取当前主题的 TxTipTheme 对象。 当小部件使用 TxTipTheme.of 时,如果主题稍后更改,它会自动重建。

可以使用 ThemeData.extension<TxTipTheme>()! 将单选框主题指定为整个 Material 主题的一部分。

Inheritance

Constructors

TxTipTheme({required TxTipThemeData data, required Widget child, Key? key})
构造一个配置所有后代 TxTip 小部件的提示主题。
const

Properties

child → Widget
The widget below this widget in the tree.
finalinherited
data → TxTipThemeData
用于所有后代 TxTip 小部件的属性。
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() → InheritedElement
Inflates this configuration to a concrete instance.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
updateShouldNotify(covariant TxTipTheme oldWidget) → bool
Whether the framework should notify widgets that inherit from this widget.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

of(BuildContext context) → TxTipThemeData
从最近的 TxTipTheme 祖先返回配置 data。