TxActionBar class
一个横置排列的操作按钮栏
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- TxActionBar
Constructors
-
TxActionBar({Key? key, ButtonStyle? buttonStyle, TextStyle? leadingTextStyle, List<
Widget> ? actions, Widget? leading, double? actionGap, ButtonStyle? iconButtonStyle, IconThemeData? iconTheme, double? minLeadingWidth, double? leadingGap, bool isActionsScrollable = false}) -
const
Properties
- actionGap → double?
-
操作按钮间的距离
final
-
actions
→ List<
Widget> ? -
操作按钮列表
final
-
按钮样式
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconButtonStyle → ButtonStyle?
-
图标按钮样式
final
- iconTheme → IconThemeData?
-
图标样式
final
- isActionsScrollable → bool
-
actions 是否可滚动
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- leading → Widget?
-
展示在操作按钮列表前的小部件
final
- leadingGap → double?
-
actions与leading之间的间距
final
- leadingTextStyle → TextStyle?
-
图标样式
final
- minLeadingWidth → double?
-
actions与leading之间的间距
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited